@@ -25,6 +25,7 @@ __all__ = ("RoutingControlStateType", "ServiceName")
 RoutingControlStateType = Literal["Off", "On"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -57,6 +58,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
